** 1) Run ODS TRACE;
**    PROC SORT does not create output objects;
ODS LISTING;
ODS TRACE ON/ LABEL;

proc sort data=sashelp.class out=class;
  by age name;
run;

ods graphics on;
proc reg data=class;
  model age=height;
run;
quit;
ods graphics off;

proc means data=class min mean max;
  class age;
  var height weight;
run;

proc contents data=class;
run;

proc print data=class;
run;

ODS TRACE OFF;

** 2) Use ODS SELECT;
** with NO SELECT;
ODS LISTING CLOSE;
ods html path='.' (url=none)
         file='get_everything.html' style=sasweb;
  title 'Get All Output Objects';
  ods graphics on;
  proc reg data=class;
    model age=height; 
  run;
  quit;
  ods graphics off;
ods html close;


** with ODS SELECT;
ODS LISTING CLOSE;
ods html file='sel_parm.html' style=sasweb;
  title 'Use ODS SELECT';
  ods html select ParameterEstimates;
  ods graphics on;
  proc reg data=class;
    model age=height; 
  run;
  quit;
  ods graphics off;
ods html close;

** 3) Use ODS EXCLUDE;
ODS LISTING CLOSE;
ods html path='.' (url=none)
         file='excl_parm.html' style=sasweb;
title 'Use ODS EXCLUDE';
ods html exclude ParameterEstimates;
ods graphics on;
proc reg data=class;
  model age=height; 
run; 
quit;
ods graphics off;
ods html close;

** 4) Use ODS OUTPUT;
ODS LISTING;
title 'Use ODS OUTPUT';
ods output ParameterEstimates=work.parmest
           FitStatistics=work.fitstat;

proc reg data=class;
  model age=height; 
run; 
quit;

options nodate nonumber ls=120;
proc print data=work.parmest;
  title 'Output Dataset Created by ODS OUTPUT for ParameterEstimates';
run;

proc print data=work.fitstat;
  title 'Output Dataset Created by ODS OUTPUT for FitStatistics';
run;

** 5) Using different "chunks" for select, exclude or output;
/* Given this OBJECT info:
Output Added:
-------------
Name:       ANOVA
Label:      Analysis of Variance
Template:   Stat.REG.ANOVA
Path:       Reg.MODEL1.Fit.Age.ANOVA
Label Path: 'The Reg Procedure'.'MODEL1'.'Fit'.Age.'Analysis of Variance'
-------------
*/

ODS OUTPUT ANOVA=work.usename
           Reg.MODEL1.Fit.Age.ANOVA=work.usepath
           Fit.Age.Anova=work.partial;

proc reg data=class;
  model age=height;
run;
quit;


** 6) Use ODS OUTPUT with multiple procedure runs;
ODS LISTING;
title;
ods output ParameterEstimates(persist=run)=work.multPE;

proc reg data=class;
  var height weight;
  model age=height; 
run; 
           
  model age=weight; 
run; 
quit;
ods output clear;


options nodate nonumber ls=120;
proc print data=work.multPE;
  title 'ODS OUTPUT for Multiple ParameterEstimate Objects';
run;

ODS TRACE OFF;




