   
options nodate nonumber orientation=portrait center missing=' ';
title;
footnote;
ods listing close;

proc sort data=employees;
  by employee_country department;
run;

** NEWFILE=PROC Option;
ods html file='report1.html' style=sasweb newfile=proc;
* ods rtf file='newfile_proc1.rtf' newfile=proc;
* ods pdf file='newfile_proc1.pdf' newfile=proc;

  title '1) Proc Report Summary';
  proc report data=employees nowd split='#';
    column org_group salary salary=salsum;
    define org_group / group 'Organization';
    define salary / n 'Count' f=comma6.;
    define salsum / sum 'Total' f=comma14.;
    rbreak after / summarize;
  run;

  title '2) Proc Tabulate Summary';
  proc tabulate data=employees f=comma8.;
    class org_group employee_country;
    var salary;
    table org_group all="All Groups",
          employee_country='Salary and Count'*(salary=' ')*(sum='Tot' n='Cnt')*f=comma14. 
                          all='All Countries'*salary=' '*(sum='Tot' n='Cnt')*f=comma14.;
  run;

  title '3) Proc Freq Report';
  proc freq data=employees;
    tables org_group*manager_levels ;
  run;

ods _all_ close;

** NEWFILE=BYGROUP option;
ods rtf file='report1.rtf' newfile=bygroup;
options nobyline;

  title '4) ByGroup Report For: #byval1';
  proc report data=employees nowd split='#';
    by employee_country;
    column org_group salary salary=salsum;
    define org_group / group 'Organization';
    define salary / n 'Count' f=comma6.;
    define salsum / sum 'Total' f=comma14.;
    rbreak after / summarize;
  run;
ods _all_ close;
options byline;


** NEWFILE=OUTPUT options;
ods pdf file='report1.pdf' newfile=output;

  title '5) Proc Univariate Report';
  proc univariate data=employees;
    var salary;
  run;

ods _all_ close;


** ID= Option;
/*
  ** This does not work;
ods html file='use_sasweb.html' style=sasweb;
ods html file='use_analysis.html' style=analysis;
proc print data=sashelp.class;
  title 'Two instances of ODS HTML';
run;
ods _all_ close;
 */
    
title;
footnote;

proc sort data=greatest.employees out=employees;
  where department in ('Administration', 'Sales') and
        employee_country in ('AU', 'BE', 'FR', 'GB');
  by department employee_country;
run;

ods html(id=1) file='file1.html' style=sasweb;
ods html(id=two) file='file2.html' style=ocean;
ods html(3) file='file3.html' style=harvest;
  proc report data=employees nowd split='#';
    title 'Report 1 ID= Behavior';
    column department salary ;
    define department / group 'Dept';
    define salary / n 'Count' f=comma14.;
    rbreak after / summarize;
  run;

ods html(two) close;

  proc report data=employees nowd split='#';
    title 'Report 2 ID= Behavior';
    column employee_country salary ;
    define employee_country / group 'Country';
    define salary / n 'Count' f=comma14.;
    rbreak after / summarize;
  run;

ods html(id=1) close;
ods html(3) close;
ods listing;





