   
options nodate nonumber orientation=portrait center;
title;
footnote;
ods listing close;

proc sort data=employees out=employees2;
  where org_group contains 'Stock';
  by employee_country department;
run;
   
** RTF and PDF methods;
ods rtf file='toc.rtf' contents=yes toc_data;
ods pdf file='toc.pdf' contents=yes;
           
** HTML based methods;
ods html(id=one) file='body1.html'
         contents='toc1.html' style=sasweb;
ods html(id=two) file='body2.html'
                 contents='toc2.html'
                 frame='frame2.html' style=analysis;

ods proclabel='First Report';
  title '1) Proc Report Summary';
  proc report data=employees2 nowd split='#'
    contents="CONTENTS= Option on PROC REPORT statement";
    column org_group salary salary=salsum;
    define org_group / group 'Organization';
    define salary / n 'Count' f=comma6.;
    define salsum / sum 'Total' f=comma14.;
    rbreak after / summarize;
  run;

ods proclabel = 'Second Report';
  title '2) Proc Tabulate Summary';
  proc tabulate data=employees2 f=comma8.
       contents="CONTENTS= Option on TABULATE statement";
    class org_group employee_country;
    var salary;
    table org_group all="All Groups",
          employee_country='Salary and Count'*(salary=' ')*(sum='Tot' n='Cnt')*f=comma14. 
                          all='All Countries'*salary=' '*(sum='Tot' n='Cnt')*f=comma14.      
      /contents="CONTENTS= Option on TABLE statement";
  run;

ods proclabel = 'Third Report';
  title '3) Summary Report';
  proc freq data=employees2;
    tables org_group*manager_levels 
       / contents="CONTENTS= Option on TABLES statement";
  run;

ods proclabel = 'Fourth Report';
  title '4) Detail Report';
  proc print data=employees2 noobs split='_'
    style(header)={vjust=b}
    contents="CONTENTS= Option on PRINT statement";
    var employee_name org_group department manager_levels;
  run;

ods _all_ close;
ods listing;

** NO TOC page will be generated if BOOKMARKGEN=NO or NOTOC is specified;
ods pdf(one) file='toc_err1.pdf' contents=yes bookmarkgen=no;
ods pdf(two) file='toc_err2.pdf' contents=yes notoc;

ods proclabel='First Report';
  title '1) Proc Report Summary';
  proc report data=employees2 nowd split='#'
    contents="CONTENTS= Option on PROC REPORT statement";
    column org_group salary salary=salsum;
    define org_group / group 'Organization';
    define salary / n 'Count' f=comma6.;
    define salsum / sum 'Total' f=comma14.;
    rbreak after / summarize;
  run;

ods proclabel = 'Second Report';
  title '2) Proc Tabulate Summary';
  proc tabulate data=employees2 f=comma8.
       contents="CONTENTS= Option on TABULATE statement";
    class org_group employee_country;
    var salary;
    table org_group all="All Groups",
          employee_country='Salary and Count'*(salary=' ')*(sum='Tot' n='Cnt')*f=comma14. 
                          all='All Countries'*salary=' '*(sum='Tot' n='Cnt')*f=comma14.      
      /contents="CONTENTS= Option on TABLE statement";
  run;

ods proclabel = 'Third Report';
  title '3) Summary Report';
  proc freq data=employees2;
    tables org_group*manager_levels 
       / contents="CONTENTS= Option on TABLES statement";
  run;

ods proclabel = 'Fourth Report';
  title '4) Detail Report';
  proc print data=employees2 noobs split='_'
    style(header)={vjust=b}
    contents="CONTENTS= Option on PRINT statement";
    var employee_name org_group department manager_levels;
  run;

ods _all_ close;
ods listing;


