data forest;
  input Study $1-16 grp OddsRatio LowerCL UpperCL Weight;
  ObsId=_N_;

  ** make some variables specifically for the plots to use;
    if grp=1 then do;
    lcl2=lowercl; 
    ucl2=uppercl;
  end;

  OR='OR'; LCL='LCL'; UCL='UCL'; wt='% Weight';

  ** create some macro variables from PCT and PCT2;
  ** the last obs will cause the correct PCT vars to be calculated;
    pct=0.75/_n_;
    pct2 = 2*pct;
    call symputx("pct", pct);
    call symputx("pct2", pct2);

  ** set formats for numeric variables;
  format oddsratio lowercl uppercl 5.3 weight 3.1;
  datalines;
Modano  (1967)    1  0.590 0.096 3.634  1
Borodan (1981)    1  0.464 0.201 1.074  3.5
Leighton (1972)   1  0.394 0.076 2.055  2
Novak   (1992)    1  0.490 0.088 2.737  2
Stawer  (1998)    1  1.250 0.479 3.261  3
Truark   (2002)   1  0.129 0.027 0.605  2.5
Fayney   (2005)   1  0.313 0.054 1.805  2
Modano  (1969)    1  0.429 0.070 2.620  2
Soloway (2000)    1  0.718 0.237 2.179  3
Adams   (1999)    1  0.143 0.082 0.250  4
Truark2  (2002)   1  0.129 0.027 0.605  2.5
Fayney2  (2005)   1  0.313 0.054 1.805  2
Modano2 (1969)    1  0.429 0.070 2.620  2
Soloway2(2000)    1  0.718 0.237 2.179  3
Adams2   (1999)   1  0.143 0.082 0.250  4
Overall           2  0.328 0.233 0.462  .
;
run;

%put pct val=&pct pct2 val = &pct2;

ods listing;
proc print data=forest; run;

proc sort data=forest out=forest;
  by descending obsid;
  run;
/*proc print data=forest; run;*/

proc template;
  define Style styles.foreststyle;
    parent = styles.analysis;
    style GraphFonts from GraphFonts                                                      
      "Fonts used in graph styles" /  
      'GraphTitleFont' = (", ",10pt,bold)
      'GraphLabelFont' = (", ",8pt) 
      'GraphValueFont' = (", ",7pt)
      'GraphDataFont' = (", ",7pt);
    style GraphData1 from GraphData1 /
      markersymbol="DiamondFilled"
      contrastcolor = GraphColors('gcdata2')                               
      color = GraphColors('gdata2')
      linestyle=1;
    style GraphData2 from GraphData2 /
      markersymbol="SquareFilled"
      contrastcolor = GraphColors('gcdata1')                               
      color = GraphColors('gdata1')
      linestyle=1;
  end;
run;

title;
options nodate nonumber;
                     
** this form of syntax needs 9.2 Phase 3 to run;
ods html close;
ods listing style=styles.foreststyle image_dpi=96;
ods graphics / reset width=7.5in height=5.25in imagename="ForestPlot_SG_1";

title "Impact of Treatment on Mortality by Study";
title2 h=8pt 'Odds Ratio and 95% CL';
proc sgplot data=forest noautolegend; 
  scatter y=study x=oddsratio / group=grp xerrorupper=ucl2 xerrorlower=lcl2;
  scatter y=study x=or / markerchar=oddsratio x2axis;
  scatter y=study x=lcl / markerchar=lowercl x2axis;
  scatter y=study x=ucl / markerchar=uppercl x2axis;
  refline 1  / axis=x;
  refline 0.01 0.1 10 100 / axis=x lineattrs=(pattern=shortdash) transparency=0.5;
  inset '               Favors Treatment'  / position=bottomleft;
  inset 'Favors Placebo'  / position=bottom;
  xaxis type=log offsetmin=0 offsetmax=0.3 min=0.01 max=100 minor display=(nolabel) ;
  x2axis offsetmin=0.75 display=(noticks nolabel);
  yaxis display=(noticks nolabel) offsetmin=&pct2 offsetmax=&pct;
run;
title;

        
ods html close;
ods listing style=styles.foreststyle image_dpi=96;
ods graphics / reset width=7.5in height=5.25in imagename="ForestPlot_SG_2";

title "Impact of Treatment on Mortality by Study";
title2 h=8pt 'Odds Ratio and 95% CL';
proc sgplot data=forest noautolegend; 
  scatter y=study x=oddsratio / group=grp xerrorupper=ucl2 xerrorlower=lcl2;
  scatter y=study x=or / markerchar=oddsratio x2axis;
  scatter y=study x=lcl / markerchar=lowercl x2axis;
  scatter y=study x=ucl / markerchar=uppercl x2axis;
  scatter y=study x=wt / markerchar=weight x2axis;
  refline 1  / axis=x;
  refline 0.01 0.1 10 100 / axis=x lineattrs=(pattern=shortdash) transparency=0.5;
  inset '               Favors Treatment'  / position=bottomleft;
  inset 'Favors Placebo'  / position=bottom;
  xaxis type=log offsetmin=0 offsetmax=0.35 min=0.01 max=100 minor display=(nolabel) ;
  x2axis offsetmin=0.7 display=(noticks nolabel);
  yaxis display=(noticks nolabel) offsetmin=&pct2 offsetmax=&pct;
run;
title;


