/* For more examples of using the SG procedures, refer to this
   paper by Susan Schwartz:
  http://www.nesug.org/proceedings/nesug08/po/po23.pdf
  
  These examples were modified from examples in this paper.
*/

data work.cancer;
  length cause $20 year $4;
  infile datalines dlm=':';
  input cause $  mcases fcases mdeaths fdeaths Year $;
  deaths=mdeaths + fdeaths;
  mcases= -1 * mcases;
  mdeaths= -1 * mdeaths;
return;
datalines;
Lung Cancer      :114760:  98620:  89510: 70880:2007
Colorectal Cancer: 55290:  57050:  26000: 26180:2007
Breast Cancer    :  2030: 178480:    450: 40460:2007
Pancreatic Cancer: 18830:  18340:  16840: 16530:2007
Prostate Cancer  :218890:      0:  27050:     0:2007
Leukemia         : 24800:  19440:  12320:  9470:2007
Lymphoma         : 38670:  32710:  10370:  9360:2007
Liver Cancer     : 13650:   5510:  11280:  5500:2007
Ovarian Cancer   :     0:  22430:      0: 15280:2007
Esophageal Cancer: 12130:   3430:  10900:  3040:2007
Bladder Cancer   : 50040:  17120:   9630:  4120:2007
Kidney Cancer    : 31590:  19600:   8080:  4810:2007
Lung Cancer      : 98300:  79800:  94400: 66000:1997
Colorectal Cancer: 45500:  48600:  22600: 24000:1997
Breast Cancer    :  1400: 180200:    290: 43900:1997
Pancreatic Cancer: 13400:  14200:  13500: 14600:1997
Prostate Cancer  :334500:      0:  41800:     0:1997
Leukemia         : 15900:  12400:  11770:  9540:1997
Lymphoma         : 34200:  26900:  13220: 12060:1997
Liver Cancer     :  9100:   4500:   7500:  4900:1997
Ovarian Cancer   :     0:  26800:      0: 14200:1997
Esophageal Cancer:  9400:   3100:   8700:  2800:1997
Bladder Cancer   : 39500:  15000:   7800:  3900:1997
Kidney Cancer    : 17100:  11700:   7000:  4300:1997
;
run;
  
** Sort the data set in descending order by deaths, so the cancer ;
** with the most deaths is first.;
proc sort data=cancer out=cancer_sorted;
  by descending deaths;
run;

** Define the picture format that will be used to display 
** the negative (male) values as positive values on the axis. 
** Both negative and positive values display with a comma
** format. The value 0 is intentionally excluded from the 
** picture format to force it to display on the axis.;
proc format;
  picture positive low-<0='000,000'
                   0<-high='000,000';
run;

ods listing style=listing;
proc sgplot data=cancer_sorted;
  where Year = '2007';
  title 'Leading Causes of US Cancer Deaths 2007';
  footnote justify=left italic 'Source: American Cancer Society';
  format mcases mdeaths fcases fdeaths positive.;
  hbar cause / response=mcases
       fillattrs=graphdata1 
       transparency=.65
       legendlabel="New Cases (Male)" name="mcases";
  hbar cause / response=mdeaths
       barwidth=.5 
       fillattrs=graphdata1 
       transparency=.25
       legendlabel="Deaths (Male)" name="mdeaths";
  hbar cause / response=fcases
       fillattrs=graphdata2 
       transparency=.65
       legendlabel="New Cases (Female)" name="fcases";
  hbar cause / response=fdeaths
       barwidth=.5 
       fillattrs=graphdata2 
       transparency=.25 
       name="fdeaths"
       legendlabel="Deaths (Female)" name="fdeaths";
         
  keylegend "mcases" "fcases" "mdeaths" "fdeaths" / across=2;
  xaxis label=" " grid;
  yaxis label=" " discreteorder=data;
run;
 
  ods listing;
proc print data=cancer_sorted;
title 'Data for Butterfly Plot';
run;
     
ods listing style=analysis;
proc sgpanel data=cancer_sorted;
  panelby Year / columns=1 uniscale=all;
  title 'Leading Causes of US Cancer Deaths 2007 vs. 1997';
  footnote justify=left italic 'Source: American Cancer Society';
  format mcases mdeaths fcases fdeaths positive.;
  hbar cause / response=mcases
       fillattrs=graphdata1 
       transparency=.65
       legendlabel="New Cases (Male)" name="mcases";
  hbar cause / response=mdeaths
       barwidth=.5 
       fillattrs=graphdata1 
       transparency=.25
       legendlabel="Deaths (Male)" name="mdeaths";
  hbar cause / response=fcases
       fillattrs=graphdata2 
       transparency=.65
       legendlabel="New Cases (Female)" name="fcases";
  hbar cause / response=fdeaths
       barwidth=.5 
       fillattrs=graphdata2 
       transparency=.25 
       name="fdeaths"
       legendlabel="Deaths (Female)" name="fdeaths";
  keylegend "mcases" "fcases" "mdeaths" "fdeaths" / across=2;
  colaxis label=" " grid;
  rowaxis label=" " discreteorder=data;
run;


** Housekeeping;
ods _all_ close;
title; footnote;
options nodate nonumber center;
ods graphics / reset=index;
ods graphics off;
ods listing style=listing;


