/* demo09_hls_color.sas
 * This program generates a color table
 * using HLS percentages to set colors and
 * then uses proc report to create
 * a table that shows color results. 
 */

** first, generate the data;
** use limited percents for lightness and saturation values;
** also use limited value for hue to keep tables smaller;
** to get a bigger list, change DO loop values here;
data hlscolors(keep=hexhue pcthue pctlite 
                    pctsat mixedcolor val);
  length pcthue hexhue $3 pctlite pctsat $2 mixedcolor $8;

  do i=0 to 360 by 30;
    hexhue = put(i,hex3.);
    pcthue = hexhue;
    do pctlite='00','33','66', '80', '99','CC','FF';
      do pctsat='00','33','66', '80', '99','CC','FF';
         mixedcolor='h'||hexhue||pctlite||pctsat;
         val = 1;
         output;
      end; /* end pctsat */
    end; /* end pctlite */
  end; /* end pcthue */
run;


** Then, use PROC REPORT to generate the report;
** Will make the report easier to page through and read;
** by using SPANROWS and BY variable;
ods listing close;

title; footnote;
options byline;
proc sort data=hlscolors;
  by hexhue;
run;

ods html file='hls_box.html' style=sasweb;

proc report data=hlscolors nowd spanrows
     style(column)={background=white
                    font_weight=bold};
 title 'HLS Color Value Lookup Chart';
 by hexhue;
 column pcthue pctlite 
        mixedcolor,pctsat val ;
 define pcthue / group 'Hue Value'  order=data;
 define pctlite / group 'Percent Lightness'  order=data;
 define pctsat / across ' ' order=data;
 define val / sum ' ' noprint;

 define mixedcolor / display "Percent Saturation" order=data;
 compute mixedcolor;
     array mval $  _c3_ _c4_ _c5_ _c6_ _c7_ _c8_  _c9_;
     do i = 1 to 7;
          subl = substr(mval(i),5,2);
          satv = substr(mval(i),7,2);

          if (subl = '99' and satv in ('CC', 'FF')) or
             (subl in ('CC', 'FF')) then
             tmp = 'style={foreground=cx000000 font_weight=bold '||
                   ' background='|| trim(mval(i))||'}';
             else tmp = 'style={foreground=cxdddddd font_weight=bold '||
                      ' background='|| trim(mval(i))||'}';
          call define('_C'||trim(left(put(i+2,2.0)))||'_','style',tmp);
       end;
    endcomp;
run;
ods html close;

ods listing; 
options byline;
 
