/* demo09_rgb_colors.sas
 * This program generates a color table
 * using RGB percentages to set colors and
 * then uses formats and proc report to create
 * a report that shows color results. 
 */

** first, generate the formats for the report;
proc format; 
  value $p_exp  '00' = '00 =  0%'
                '33' = '33 = 20%'
                '66' = '66 = 40%'
                '99' = '99 = 60%'
                'CC' = 'CC = 80%'
                'FF' = 'FF = 100%';

  value $pctr '00' = 'cx000000'
              '33' = 'cx330000'
              '66' = 'cx660000'
              '99' = 'cx990000'
              'CC' = 'cxCC0000'
              'FF' = 'cxFF0000';
  value $pctg '00' = 'cx000000'
              '33' = 'cx003300'
              '66' = 'cx006600'
              '99' = 'cx009900'
              'CC' = 'cx00CC00'
              'FF' = 'cx00FF00';
  value $pctb '00' = 'cx000000'
              '33' = 'cx000033'
              '66' = 'cx000066'
              '99' = 'cx000099'
              'CC' = 'cx0000CC'
              'FF' = 'cx0000FF';
run;

** next, generate the data;
** use the 256 non-dithering colors;
** to get a bigger list, change HEX values here;
data rgbcolors(keep=brkval pctred  pctgreen 
                    pctblue mixedcolor val);
  length pctred pctgreen pctblue $2 mixedcolor $8;

  do pctred='00','33','66','99','CC','FF';
    brkval = pctred;
    do pctgreen='00','33','66','99','CC','FF';
      do pctblue='00','33','66','99','CC','FF';
         mixedcolor='cx'||pctred||pctgreen||pctblue;
         val = 1;
         output;
      end; /* end pctblue */
    end; /* end pctgreen */
  end; /* end pctred */
  format brkval $p_exp.;
run;

options nobyline;
ods html file='RGB_box.html' style=sasweb;

proc report data=rgbcolors nowd spanrows
     style(column)={background=white
                    font_weight=bold
                    foreground=cxffffff};
 title 'RGB Color Value Lookup Chart';
 title2 'Percent of Red #byval(brkval)';
 by brkval;
 column pctred pctgreen 
        mixedcolor,pctblue val ;
 define pctred / group 'Percent Red' f=$p_exp. order=data
                  style(column)={background=$pctr.};
 define pctgreen / group 'Percent Green' f=$p_exp. order=data
                  style(column)={background=$pctg.};
 define pctblue / across ' ' f=$p_exp. order=data
                  style(column)={background=$pctb.};
 define val / sum ' ' noprint;

 define mixedcolor / display "Percent Blue" order=data;
 compute mixedcolor;
     array mval $  _c3_ _c4_ _c5_ _c6_ _c7_ _c8_  ;
     do i = 1 to 6;
          subg = substr(mval(i),5,2);
          subr = substr(mval(i),3,2);
          if subg in ('CC', 'FF') or
             subr in ('FF') then
             tmp = 'style={foreground=cx000000 font_weight=bold '||
                   ' background='|| trim(mval(i))||'}';
             else tmp = 'style={foreground=cxffffff font_weight=bold '||
                      ' background='|| trim(mval(i))||'}';
          call define('_C'||trim(left(put(i+2,2.0)))||'_','style',tmp);
       end;
    endcomp;
run;
ods html close;

title; footnote;
ods listing; 
options byline;
 
