title; footnote;
options nodate nonumber center;
               
proc sort data=sashelp.shoes out=shoes;
  where region in ('Asia', 'Canada', 'Pacific') and
        product in ('Boot', 'Sandal', 'Slipper');
  by region product;
run;

data class(keep=sex name_age ht_wt);
  length name_age $50 ht_wt $50 namestr agestr htstr wtstr $15;
  set sashelp.class (obs=3);
  namestr = 'Name: '||left(name);
  agestr = 'Age: '||put(age,2.0);
  htstr = 'Height: '||put(height,4.1);
  wtstr = 'Weight: '||put(weight,4.1);
  name_age = catx('^{newline 1}',namestr,agestr);
  ht_wt = catx('^{newline 1}',htstr,wtstr);
run;

ods html file='use_ESC_style.html' style=journal;
ods rtf file='use_ESC_style.rtf' style=journal startpage=no;  
ods pdf file='use_ESC_style.pdf' style=journal startpage=no;  

ods escapechar='^';

proc report data=shoes nowd;
  title 'Use ESCAPECHAR and {STYLE} ^{super 1}';
  column region sales,product;
  define region / group 
         style(header)={font_face='Courier New'};
  define product / across '^{style[textdecoration=underline]Product Underlined}'
         style(header)={font_weight=bold font_face='Courier New'};
  define sales / sum ' ';
run;

footnote j=l '^{super 1} The Footnote';
proc report data=class nowd;
  title;
  column sex 
    ('^{style[textdecoration=underline]LineFeed in Var Value}' name_age ht_wt);
  define sex / order;
  define name_age / display 'Name and Age';
  define ht_wt / display 'Height and Weight';
run;

ods _all_ close;
